
![Architecture](architecture.png)

## To-Do List

### VNI
- [x] Handle cpds computation
- [x] Handle intervention
- [x] Handle high dimensional data in VNI
- [x] Handle intervention with an entire set of feature values -> hint: use uniform distribution
- [ ] Develop tests
- [X] Handle Batch of Queries
- [ ] Define new interventional distributions
- [ ] Add visualization plots

### KDE
- [ ] Develop tests
- [X] Handle Batch of Queries
- [ ] New kernels
- [X] Handle Query with Multi-Target
- [ ] Update Prior

### Usage
- [ ] Usage for benchmark
- [ ] Usage for single prediction vs batch prediction
- [ ] Usage for planning - representation

### Repo
- [ ] Update architecture scheme
- [ ] Documentations
- [ ] Website
